import sys

from PyQt4 import QtGui, QtCore
from PyQt4.QtCore import QDir, Qt, QFileInfo
from PyQt4.QtGui import QSplitter


class FileBrowser(QSplitter):
    def __init__(self, parent = None):
        super(FileBrowser, self).__init__(parent)

        # Directory tree and model
        self.__dirModel = QtGui.QFileSystemModel()
        self.__dirModel.setFilter(QDir.AllDirs | QDir.NoDotAndDotDot)

        self.__dirView = self._setupTreeView()
        self.__dirView.setModel(self.__dirModel)
        self.__dirView.setRootIndex(
            self.__dirModel.setRootPath(QDir.rootPath()))
        self.__dirView.hideColumn(1)
        self.__dirView.hideColumn(2)

        self.__dirView.setSelectionMode(QtGui.QAbstractItemView.SingleSelection)
        self.__dirView.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
        self.__dirView.selectionModel().currentChanged.connect(self.updateFiles)

        # File tree and model
        self.__fileModel = QtGui.QFileSystemModel()
        self.__fileModel.setFilter(QDir.Files)

        self.__fileView = self._setupTreeView()
        self.__fileView.setModel(self.__fileModel)
        self.__fileView.setRootIsDecorated(False)
        self.__fileView.setItemsExpandable(False)

        # Splitter layout
        self.setOrientation(Qt.Horizontal)
        self.addWidget(self.__dirView)
        self.addWidget(self.__fileView)

        # Default sorting and start location (homePath)
        self.__dirView.sortByColumn(0, Qt.AscendingOrder)
        self.__fileView.sortByColumn(2, Qt.AscendingOrder)
        self.__dirView.setCurrentIndex(
            self.__dirModel.index(QDir.homePath()))


    def _setupTreeView(self):
        result = QtGui.QTreeView(self)
        result.setSortingEnabled(True)
        result.setAlternatingRowColors(True)
        result.setAnimated(True)
        result.header().setResizeMode(QtGui.QHeaderView.ResizeToContents)
        return result


    @QtCore.pyqtSlot('QModelIndex')
    def updateFiles(self,  index):
        dirPath = self.__dirModel.filePath(index)
        self.__fileModel.setRootPath(dirPath)
        self.__fileView.setRootIndex(self.__fileModel.index(dirPath))



if __name__ == '__main__':
    app = QtGui.QApplication(sys.argv)
    MainWindowClass = QtGui.QMainWindow()
    fileb = FileBrowser()
    fileb.resize(1000, 600)
    fileb.show()
    sys.exit(app.exec_())
